import { CameraOutlined } from "@ant-design/icons";
import { Button, Card, Col, Input, Result, Row, Typography } from "antd";
import { AppStyle, Constants, myFetch } from "../../utils";
import { useEffect, useState } from "react";
import { QrScanner } from "@yudiel/react-qr-scanner";
import EquipmentViewModal from "./EquipmentViewModal";
import CreateEquipmentDocumentationModal, {
  NoteComponent,
} from "./CreateEquipmentDocumentationModal";
import { Link } from "react-router-dom";

export default function EquipmentDocumentation({ isEquipmentCreateModalOpen }) {
  const [isScannerActive, setIsScannerActive] = useState(false);
  // const [fetchingEquipment, setFetchingEquipment] = useState(false);
  const [scannerResult, setScannerResult] = useState("");
  const [equipmentDocumentation, setEquipmentDocumentation] = useState([]);

  useEffect(() => {
    console.log("scannerResult", scannerResult);

    if (scannerResult === "") return;

    myFetch(`/equipment/documentation/${scannerResult}`, "GET").then((data) => {
      console.log("data", data);

      setEquipmentDocumentation(data);

      //setEquipment(data);
      //setFetchingEquipment(false);
    });
  }, [scannerResult]);

  // const [equipment, setEquipment] = useState([]);

  /*useEffect(() => {
    console.log("eq");

    setFetchingEquipment(true);

    myFetch("/equipment", "GET").then((data) => {
      setEquipment(data);
      setFetchingEquipment(false);
    });
  }, []);

  const getTableColumns = () => {
    return [
      {
        title: "Name",
        dataIndex: "name",
        key: "name",
      },
      {
        title: "Last modification",
        dataIndex: "lastModification",
        key: "lastModification",
      },
      {
        title: "Last modified at",
        dataIndex: "lastModifiedAt",
        key: "lastModifiedAt",
      },
      {
        title: "Action",
        dataIndex: "action",
        key: "action",
        render: (_, record) => {
          return (
            <Link
              to={
                Constants.ROUTE_PATHS.EQUIPMENT_DOCUMENTATION_VIEW + record.key
              }
            >
              View
            </Link>
          );
        },
      },
    ];
  };

  const getTableItems = () => {
    return equipment.map((eq) => ({
      key: eq.Id,
      name: (
        <>
          <Popover
            placement="right"
            trigger="hover"
            content={
              <Avatar
                src={`${Constants.API_ADDRESS}/equipment/thumbnail${eq.Thumbnail}`}
                size={256}
                shape="square"
              />
            }
          >
            <>
              <Avatar
                src={`${Constants.API_ADDRESS}/equipment/thumbnail${eq.Thumbnail}`}
                shape="square"
              />
            </>
          </Popover>

          {eq.Name}
        </>
      ),
    }));
  }; */

  const CreateDocumentationButton = () => {
    return (
      <Link
        to={`${Constants.ROUTE_PATHS.EQUIPMENT_DOCUMENTATION_CREATE}${scannerResult}`}
      >
        <Button type="primary">Create documentation</Button>
      </Link>
    );
  };

  const DocumentationContent = ({ documentation }) => {
    console.log("doc", documentation);

    return (
      <Card>
        <Typography.Title level={4}>{documentation.Title}</Typography.Title>

        {documentation.Notes !== "" &&
          JSON.parse(documentation.Notes).map((note, index) => (
            <NoteComponent
              key={index}
              viewMode
              image={`${Constants.STATIC_CONTENT_ADDRESS}equipmentdocumentation/${documentation.Id}/${note.Image}`}
              description={note.Description}
            />
          ))}
      </Card>
    );
  };

  return (
    <>
      <Row style={{ marginBottom: AppStyle.app.marginBottom }}>
        <Col xs={0} sm={7} />
        <Col xs={24} sm={10}>
          <Card
            style={{
              textAlign: "center",
            }}
          >
            {isScannerActive ? (
              <>
                <QrScanner
                  onDecode={(result) => {
                    console.log(result);
                    setScannerResult(result);
                    setIsScannerActive(false);
                  }}
                  onError={(error) => console.log(error?.message)}
                />
                <Button onClick={() => setIsScannerActive(false)}>
                  Close camera
                </Button>
              </>
            ) : (
              <div onClick={() => setIsScannerActive(true)}>
                <CameraOutlined style={{ fontSize: 64 }} />
                <Typography.Title level={5}>Scan equipment</Typography.Title>
              </div>
            )}
            Result: {scannerResult}
            <Input placeholder="Equipment id" />
            <Button onClick={() => setScannerResult("169")}>Search</Button>
          </Card>
        </Col>
        <Col xs={0} sm={7} />
      </Row>

      <h1>ScannerResult: {scannerResult}</h1>

      {scannerResult !== "" && equipmentDocumentation.length === 0 ? (
        <Result
          status="404"
          title="404"
          subTitle="Sorry, for the equipment does not exist an documentation."
          extra={
            <>
              <Button onClick={() => setScannerResult("")}>
                Back to Overview
              </Button>

              <CreateDocumentationButton />
            </>
          }
        />
      ) : (
        <>
          <CreateDocumentationButton />

          {equipmentDocumentation.map((documentation, index) => (
            <DocumentationContent key={index} documentation={documentation} />
          ))}
        </>
      )}

      <CreateEquipmentDocumentationModal isOpen={isEquipmentCreateModalOpen} />
    </>
  );
}

export function DocumentationImage({ image, imgStyle }) {
  return image ? (
    <img
      src={image}
      style={{
        width: "100%",
        ...imgStyle,
      }}
      alt="Preview"
    />
  ) : (
    <div
      style={{
        height: 250,
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
      }}
    >
      No image selected
    </div>
  );
}

/* <EquipmentViewModal isOpen={isEquipmentViewModalOpen} />
<Table
        loading={fetchingEquipment}
        scroll={{ x: "max-content" }}
        columns={getTableColumns()}
        dataSource={getTableItems()}
      />
*/
